==> rc-ui-lib-2.1.1.tgz: package/es/radio/Radio.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import React, { useContext, useMemo } from "react";
import RadioContext from "./RadioContext";
import Checker from "../checkbox/Checker";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const Radio = (props) => {
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("radio", prefixCls);
  const _a = useContext(RadioContext), {
    parent
  } = _a, context = __objRest(_a, [
    "parent"
  ]);
  const checked = useMemo(() => {
    return parent ? context.checked === props.name : props.checked;
  }, [context.checked]);
  const toggle = () => {
    const emitter = parent ? context.toggle : () => {
    };
    emitter(props.name);
  };
  return /* @__PURE__ */ React.createElement(Checker, _extends({}, props, {
    bem,
    role: "radio",
    parent,
    checked,
    onToggle: toggle
  }));
};
var stdin_default = Radio;
export {
  stdin_default as default
};

==> rc-ui-lib-2.1.3.tgz: package/es/radio/Radio.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t)
        ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import React, { useContext, useMemo } from "react";
import RadioContext from "./RadioContext";
import Checker from "../checkbox/Checker";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const Radio = (props) => {
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("radio", prefixCls);
  const _a = useContext(RadioContext), {
    parent
  } = _a, context = __objRest(_a, [
    "parent"
  ]);
  const checked = useMemo(() => {
    return parent ? context.checked === props.name : props.checked;
  }, [context.checked]);
  const toggle = () => {
    const emitter = parent ? context.toggle : () => {
    };
    emitter(props.name);
  };
  return /* @__PURE__ */ React.createElement(Checker, _extends({}, props, {
    bem,
    role: "radio",
    parent,
    checked,
    onToggle: toggle
  }));
};
var stdin_default = Radio;
export {
  stdin_default as default
};
